
import os
import sysconfig

from distutils import sysconfig as du_sysconfig

from . import project_setup_py_test


@project_setup_py_test("issue-284-build-ext-inplace", ["build_ext", "--inplace"], disable_languages_test=True)
def test_build_ext_inplace_command():
    assert os.path.exists('hello/_hello_sk%s' % sysconfig.get_config_var('SO'))

    # See issue scikit-build #383
    assert os.path.exists('hello/_hello_ext%s' % du_sysconfig.get_config_var('SO'))



"""
This module defines constants commonly used in scikit-build.
"""

import os
import sys

from distutils.util import get_platform

CMAKE_DEFAULT_EXECUTABLE = "cmake"
"""Default path to CMake executable."""

_SKBUILD_PLAT_NAME = get_platform()


def set_skbuild_plat_name(plat_name):
    """Set platform name associated with scikit-build functions returning a path:

    * :func:`SKBUILD_DIR()`
    * :func:`SKBUILD_MARKER_FILE()`
    * :func:`CMAKE_BUILD_DIR()`
    * :func:`CMAKE_INSTALL_DIR()`
    * :func:`CMAKE_SPEC_FILE()`
    * :func:`SETUPTOOLS_INSTALL_DIR()`
    """
    global _SKBUILD_PLAT_NAME
    _SKBUILD_PLAT_NAME = plat_name


def skbuild_plat_name():
    """Get platform name.

    Default value corresponds to :func:`distutils.util.get_platform()` and can be overridden
    with :func:`set_skbuild_plat_name()`.
    """
    return _SKBUILD_PLAT_NAME


def SKBUILD_DIR():
    """Top-level directory where setuptools and CMake directories are generated."""
    return os.path.join(
        "_skbuild",
        "{}-{}".format(_SKBUILD_PLAT_NAME, '.'.join(map(str, sys.version_info[:2]))),
    )


def SKBUILD_MARKER_FILE():
    """Marker file used by :func:`skbuild.command.generate_source_manifest.generate_source_manifest.run()`."""
    return os.path.join(SKBUILD_DIR(), "_skbuild_MANIFEST")


def CMAKE_BUILD_DIR():
    """CMake build directory."""
    return os.path.join(SKBUILD_DIR(), "cmake-build")


def CMAKE_INSTALL_DIR():
    """CMake install directory."""
    return os.path.join(SKBUILD_DIR(), "cmake-install")


def CMAKE_SPEC_FILE():
    """CMake specification file storing CMake version, CMake configuration arguments and
    environment variables ``PYTHONNOUSERSITE`` and ``PYTHONPATH``.
    """
    return os.path.join(CMAKE_BUILD_DIR(), "CMakeSpec.json")


def SETUPTOOLS_INSTALL_DIR():
    """Setuptools install directory."""
    return os.path.join(SKBUILD_DIR(), "setuptools")




import glob

from . import (
    _tmpdir, check_wheel_content, execute_setup_py, initialize_git_repo_and_commit, prepare_project
)


def test_bdist_wheel_command():
    project = "issue-335-support-cmake-source-dir"

    expected_content = [
        'hello/__init__.py',
        'hello/swig_mwe.py',
        'hello/_swig_mwe.so',
        'hello-1.2.3.data/data/bin/hello',
        'hello-1.2.3.data/data/lib/static/libbar.a',
        'hello-1.2.3.data/data/lib/static/libfoo.a',
        'hello-1.2.3.data/data/include/bar.h',
        'hello-1.2.3.data/data/include/foo.h'
    ]

    expected_distribution_name = 'hello-1.2.3'

    tmp_dir = _tmpdir('test_bdist_wheel_command')
    prepare_project(project, tmp_dir)
    initialize_git_repo_and_commit(tmp_dir, verbose=True)

    relative_setup_path = 'wrapping/python/'

    with execute_setup_py(tmp_dir.join(relative_setup_path), ["bdist_wheel"]):
        whls = glob.glob('dist/*.whl')
        assert len(whls) == 1
        check_wheel_content(whls[0], expected_distribution_name, expected_content)
